from setuptools import setup, find_packages

setup(
    name ="anas1",
    version="1.0",
    author="anaskhaan",
    author_email="m.anaskhan9861@gmail.com",
    description="This is just a test package",
    packages=find_packages(),
    python_requires=">3.6",
    entry_point={
        "console_script" : ["m.anaskhan9861@gmail.com"],
        
        },
    )